import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-DOcVZxnt.js";import"./vendor-firebase-yTFzdAQf.js";import{D as t}from"./vendor-vue-core-CvBSzfTV.js";import"./vendor-other-ZVm7XS8K.js";import{r as n}from"./useFeatureFlags-CMK9o9Rw.js";import"./api-OgmjiUkn.js";import"./colorUtil-C9tyO6rZ.js";import{o as r}from"./i18n-S80A-Sy1.js";import"./vendor-reka-ui-EFkcZtPy.js";import"./Button-C-kbn1lh.js";import{Ut as i}from"./dialogService-Dp405gae.js";import"./systemStatsStore-BAnEcJS2.js";import"./useErrorHandling-DfKSzlg9.js";import"./dialogStore-BDXSs8Ic.js";import"./userStore-C5cqCkur.js";import"./useCopyToClipboard-_eFTtqIy.js";import"./vendor-tiptap-BZCaYoPl.js";import"./vendor-markdown-Gcn_JH9N.js";import"./markdownRendererUtil-BD0lrBqH.js";import"./useExternalLink-CZSEXO8Q.js";var a=t(()=>{let e=[],t=n.value.server_health_alert;return t&&e.push({text:t.message,label:t.badge,variant:t.severity??`error`,tooltip:t.tooltip}),e.push({label:r(`g.beta`),text:`Comfy Cloud`}),e});i().registerExtension({name:`Comfy.Cloud.Badges`,get topbarBadges(){return a.value}});
//# sourceMappingURL=cloudBadges-_MvtOhld.js.map