import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import{t}from"./types-Bc3W4AWd.js";const n={DISTRIBUTION:`tf_42243568391700`,ANONYMOUS_EMAIL:`tf_anonymous_requester_email`,EMAIL:`tf_40029135130388`,USER_ID:`tf_42515251051412`};function getDistribution(){return t?`ccloud`:`oss-nightly`}var r=`https://support.comfy.org/hc/en-us/requests/new`;function buildSupportUrl(e){let t=new URLSearchParams({[n.DISTRIBUTION]:getDistribution()});return e?.userEmail&&(t.append(n.ANONYMOUS_EMAIL,e.userEmail),t.append(n.EMAIL,e.userEmail)),e?.userId&&t.append(n.USER_ID,e.userId),`${r}?${t.toString()}`}export{buildSupportUrl as n,getDistribution as r,n as t};
//# sourceMappingURL=config-DFoXI2Xv.js.map