import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-DOcVZxnt.js";import"./vendor-firebase-yTFzdAQf.js";import"./vendor-other-ZVm7XS8K.js";import"./useFeatureFlags-CMK9o9Rw.js";import"./api-OgmjiUkn.js";import"./colorUtil-C9tyO6rZ.js";import{o as t}from"./i18n-S80A-Sy1.js";import"./vendor-reka-ui-EFkcZtPy.js";import"./Button-C-kbn1lh.js";import{Ut as n}from"./dialogService-Dp405gae.js";import"./systemStatsStore-BAnEcJS2.js";import"./useErrorHandling-DfKSzlg9.js";import"./dialogStore-BDXSs8Ic.js";import"./userStore-C5cqCkur.js";import"./useCopyToClipboard-_eFTtqIy.js";import"./vendor-tiptap-BZCaYoPl.js";import"./vendor-markdown-Gcn_JH9N.js";import"./markdownRendererUtil-BD0lrBqH.js";import"./useExternalLink-CZSEXO8Q.js";import{r,t as i}from"./config-DFoXI2Xv.js";var a=`https://support.comfy.org/hc/en-us/requests/new`,o=`43066738713236`,s=r(),c=`${a}?${new URLSearchParams({ticket_form_id:o,[i.DISTRIBUTION]:s}).toString()}`,l=[{icon:`icon-[lucide--message-circle-question-mark]`,label:t(`actionbar.feedback`),tooltip:t(`actionbar.feedbackTooltip`),onClick:()=>{window.open(c,`_blank`,`noopener,noreferrer`)}}];n().registerExtension({name:`Comfy.Cloud.FeedbackButton`,actionBarButtons:l});
//# sourceMappingURL=cloudFeedbackTopbarButton-D0imZhQK.js.map