import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import{i as t,n}from"./vendor-primevue-DOcVZxnt.js";import"./vendor-firebase-yTFzdAQf.js";import{Dt as r,F as i,I as a,It as o,R as s,Vt as c,et as l,gt as u,k as d}from"./vendor-vue-core-CvBSzfTV.js";import"./vendor-other-ZVm7XS8K.js";import"./useFeatureFlags-CMK9o9Rw.js";import"./api-OgmjiUkn.js";import"./colorUtil-C9tyO6rZ.js";import"./i18n-S80A-Sy1.js";import"./vendor-reka-ui-EFkcZtPy.js";import{t as f}from"./Button-C-kbn1lh.js";import{Un as p}from"./dialogService-Dp405gae.js";import"./systemStatsStore-BAnEcJS2.js";import"./useErrorHandling-DfKSzlg9.js";import"./dialogStore-BDXSs8Ic.js";import"./userStore-C5cqCkur.js";import"./useCopyToClipboard-_eFTtqIy.js";import"./vendor-tiptap-BZCaYoPl.js";import"./vendor-markdown-Gcn_JH9N.js";import"./markdownRendererUtil-BD0lrBqH.js";import"./useExternalLink-CZSEXO8Q.js";import{i as m}from"./signInSchema-WUzmL51F.js";import{t as h}from"./PasswordFields-UW7dSFY7.js";var g=s({__name:`UpdatePasswordContent`,props:{onSuccess:{type:Function}},setup(e){let s=p(),g=r(!1),onSubmit=async t=>{if(t.valid){g.value=!0;try{await s.updatePassword(t.values.password),e.onSuccess()}finally{g.value=!1}}};return(e,r)=>(l(),d(o(t),{class:`flex w-96 flex-col gap-6`,resolver:o(n)(o(m)),onSubmit},{default:u(()=>[a(h),a(f,{type:`submit`,class:`mt-4 h-10 font-medium`,loading:g.value},{default:u(()=>[i(c(e.$t(`userSettings.updatePassword`)),1)]),_:1},8,[`loading`])]),_:1},8,[`resolver`]))}});export{g as default};
//# sourceMappingURL=UpdatePasswordContent-UKLpo6cs.js.map