import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-DOcVZxnt.js";import"./vendor-firebase-yTFzdAQf.js";import{F as t,I as n,It as r,O as i,R as a,Vt as o,et as s,gt as c,j as l}from"./vendor-vue-core-CvBSzfTV.js";import"./vendor-other-ZVm7XS8K.js";import"./useFeatureFlags-CMK9o9Rw.js";import"./api-OgmjiUkn.js";import"./colorUtil-C9tyO6rZ.js";import"./i18n-S80A-Sy1.js";import"./vendor-reka-ui-EFkcZtPy.js";import{t as u}from"./Button-C-kbn1lh.js";import{Wn as d}from"./dialogService-Dp405gae.js";import"./systemStatsStore-BAnEcJS2.js";import"./useErrorHandling-DfKSzlg9.js";import{t as f}from"./dialogStore-BDXSs8Ic.js";import"./userStore-C5cqCkur.js";import"./useCopyToClipboard-_eFTtqIy.js";import"./vendor-tiptap-BZCaYoPl.js";import"./vendor-markdown-Gcn_JH9N.js";import"./markdownRendererUtil-BD0lrBqH.js";import"./useExternalLink-CZSEXO8Q.js";var p={class:`flex w-full max-w-[512px] flex-col rounded-2xl border border-border-default bg-base-background`},m={class:`flex h-12 items-center justify-between border-b border-border-default px-4`},h={class:`m-0 text-sm font-normal text-base-foreground`},g=[`aria-label`],_={class:`flex flex-col gap-4 px-4 py-4`},v={class:`m-0 text-sm text-muted-foreground`},y={class:`flex items-center justify-end gap-4 px-4 py-4`},b=a({__name:`InviteMemberUpsellDialogContent`,setup(e){let a=f(),{isActiveSubscription:b,showSubscriptionDialog:x}=d();function onDismiss(){a.closeDialog({key:`invite-member-upsell`})}function onUpgrade(){a.closeDialog({key:`invite-member-upsell`}),x()}return(e,a)=>(s(),l(`div`,p,[i(`div`,m,[i(`h2`,h,o(r(b)?e.$t(`workspacePanel.inviteUpsellDialog.titleSingleSeat`):e.$t(`workspacePanel.inviteUpsellDialog.titleNotSubscribed`)),1),i(`button`,{class:`cursor-pointer rounded border-none bg-transparent p-0 text-muted-foreground transition-colors hover:text-base-foreground focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-secondary-foreground`,"aria-label":e.$t(`g.close`),onClick:onDismiss},a[0]||=[i(`i`,{class:`pi pi-times size-4`},null,-1)],8,g)]),i(`div`,_,[i(`p`,v,o(r(b)?e.$t(`workspacePanel.inviteUpsellDialog.messageSingleSeat`):e.$t(`workspacePanel.inviteUpsellDialog.messageNotSubscribed`)),1)]),i(`div`,y,[n(u,{variant:`muted-textonly`,onClick:onDismiss},{default:c(()=>[t(o(e.$t(`g.cancel`)),1)]),_:1}),n(u,{variant:`primary`,size:`lg`,onClick:onUpgrade},{default:c(()=>[t(o(r(b)?e.$t(`workspacePanel.inviteUpsellDialog.upgradeToCreator`):e.$t(`workspacePanel.inviteUpsellDialog.viewPlans`)),1)]),_:1})])]))}});export{b as default};
//# sourceMappingURL=InviteMemberUpsellDialogContent-Dh5ctxvl.js.map