import"./vendor-primevue-DOcVZxnt.js";import"./vendor-other-ZVm7XS8K.js";import"./api-OgmjiUkn.js";import"./colorUtil-C9tyO6rZ.js";import"./i18n-S80A-Sy1.js";import{n as e,r as t,t as n}from"./auth-B0-aRtMd.js";export{n as getSurveyCompletedStatus};