import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-DOcVZxnt.js";import"./vendor-firebase-yTFzdAQf.js";import{D as t,It as n,R as r,et as i,k as a,ot as o}from"./vendor-vue-core-CvBSzfTV.js";import"./vendor-other-ZVm7XS8K.js";import"./useFeatureFlags-CMK9o9Rw.js";import"./api-OgmjiUkn.js";import"./colorUtil-C9tyO6rZ.js";import"./i18n-S80A-Sy1.js";import"./vendor-reka-ui-EFkcZtPy.js";import"./Button-C-kbn1lh.js";import{Wn as s}from"./dialogService-Dp405gae.js";import"./systemStatsStore-BAnEcJS2.js";import"./useErrorHandling-DfKSzlg9.js";import"./dialogStore-BDXSs8Ic.js";import"./userStore-C5cqCkur.js";import"./useCopyToClipboard-_eFTtqIy.js";import"./vendor-tiptap-BZCaYoPl.js";import"./vendor-markdown-Gcn_JH9N.js";import"./markdownRendererUtil-BD0lrBqH.js";import"./useExternalLink-CZSEXO8Q.js";import{t as c}from"./ComfyQueueButton-CgY6GS33.js";import{t as l}from"./SubscribeToRun-DY0vKVQd.js";var u=r({__name:`CloudRunButtonWrapper`,setup(e){let{isActiveSubscription:r}=s(),u=t(()=>r.value?c:l);return(e,t)=>(i(),a(o(u.value),{key:n(r)?`queue`:`subscribe`}))}});export{u as default};
//# sourceMappingURL=CloudRunButtonWrapper-DsMV2UZu.js.map